@@ -1,5 +1,4 @@
 import logging
-
 from functools import reduce
 from operator import mul as operator_mul
 
@@ -31,10 +30,49 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
     reference, and domain ancillary constructs; as well as properties
     to describe the domain.
 
+    **NetCDF interface**
+
+    {{netCDF variable}}
+
+    {{netCDF global attributes}}
+
+    {{netCDF group attributes}}
+
+    {{netCDF geometry group}}
+
+    Some components exist within multiple constructs, but when written
+    to a netCDF dataset the netCDF names associated with such
+    components will be arbitrarily taken from one of them. The netCDF
+    variable, dimension and sample dimension names and group
+    structures for such components may be set or removed consistently
+    across all such components with the `nc_del_component_variable`,
+    `nc_set_component_variable`, `nc_set_component_variable_groups`,
+    `nc_clear_component_variable_groups`,
+    `nc_del_component_dimension`, `nc_set_component_dimension`,
+    `nc_set_component_dimension_groups`,
+    `nc_clear_component_dimension_groups`,
+    `nc_del_component_sample_dimension`,
+    `nc_set_component_sample_dimension`,
+    `nc_set_component_sample_dimension_groups`,
+    `nc_clear_component_sample_dimension_groups` methods.
+
+    A domain construct of the CF data model.
+
+    The domain represents a set of discrete "locations" in what
+    generally would be a multi-dimensional space, either in the real
+    world or in a model's simulated world. The data array elements of
+    a field construct correspond to individual location of a domain.
+
+    The domain construct is defined collectively by the following
+    constructs of the CF data model: domain axis, dimension
+    coordinate, auxiliary coordinate, cell measure, coordinate
+    reference, and domain ancillary constructs; as well as properties
+    to describe the domain.
+
     """
 
     def __new__(cls, *args, **kwargs):
-        """"""
+        """Creates a new Domain instance."""
         instance = super().__new__(cls)
         instance._Data = Data
         instance._Constructs = Constructs
@@ -479,69 +517,68 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
     def identity(self, default="", strict=False, relaxed=False, nc_only=False):
         """Return the canonical identity.
 
-            By default the identity is the first found of the following:
+        By default the identity is the first found of the following:
 
-            * The "id" attribute, preceded by ``'id%'``.
-            * The "cf_role" property, preceded by ``'cf_role='``.
-            * The "long_name" property, preceded by ``'long_name='``.
-            * The netCDF variable name, preceded by ``'ncvar%'``.
-            * The value of the *default* parameter.
+        * The "id" attribute, preceded by ``'id%'``.
+        * The "cf_role" property, preceded by ``'cf_role='``.
+        * The "long_name" property, preceded by ``'long_name='``.
+        * The netCDF variable name, preceded by ``'ncvar%'``.
+        * The value of the *default* parameter.
 
-            .. versionadded:: 3.11.0
+        .. versionadded:: 3.11.0
 
-            .. seealso:: `id`, `identities`
+        .. seealso:: `id`, `identities`
 
-            :Parameters:
+        :Parameters:
 
-                default: optional
-                    If no identity can be found then return the value of the
-                    default parameter.
+            default: optional
+                If no identity can be found then return the value of the
+                default parameter.
 
-                strict: `bool`, optional
-                    If True then the identity is the first found of only the
-                    "standard_name" property or the "id" attribute.
+            strict: `bool`, optional
+                If True then the identity is the first found of only the
+                "standard_name" property or the "id" attribute.
 
-                relaxed: `bool`, optional
-                    If True then the identity is the first found of only the
-                    "standard_name" property, the "id" attribute, the
-                    "long_name" property or the netCDF variable name.
+            relaxed: `bool`, optional
+                If True then the identity is the first found of only the
+                "standard_name" property, the "id" attribute, the
+                "long_name" property or the netCDF variable name.
 
-                nc_only: `bool`, optional
-                    If True then only take the identity from the netCDF
-                    variable name.
+            nc_only: `bool`, optional
+                If True then only take the identity from the netCDF
+                variable name.
 
-            :Returns:
+        :Returns:
 
-                    The identity.
+                The identity.
 
-            **Examples:**
+        **Examples:**
 
-        TODO
-            >>> f.properties()
-            {'foo': 'bar',
-             'long_name': 'Air Temperature',
-             'standard_name': 'air_temperature'}
-            >>> f.nc_get_variable()
-            'tas'
-            >>> f.identity()
-            'air_temperature'
-            >>> f.del_property('standard_name')
-            'air_temperature'
-            >>> f.identity(default='no identity')
-            'air_temperature'
-            >>> f.identity()
-            'long_name=Air Temperature'
-            >>> f.del_property('long_name')
-            >>> f.identity()
-            'ncvar%tas'
-            >>> f.nc_del_variable()
-            'tas'
-            >>> f.identity()
-            'ncvar%tas'
-            >>> f.identity()
-            ''
-            >>> f.identity(default='no identity')
-            'no identity'
+        >>> f.properties()
+        {'foo': 'bar',
+         'long_name': 'Air Temperature',
+         'standard_name': 'air_temperature'}
+        >>> f.nc_get_variable()
+        'tas'
+        >>> f.identity()
+        'air_temperature'
+        >>> f.del_property('standard_name')
+        'air_temperature'
+        >>> f.identity(default='no identity')
+        'air_temperature'
+        >>> f.identity()
+        'long_name=Air Temperature'
+        >>> f.del_property('long_name')
+        >>> f.identity()
+        'ncvar%tas'
+        >>> f.nc_del_variable()
+        'tas'
+        >>> f.identity()
+        'ncvar%tas'
+        >>> f.identity()
+        ''
+        >>> f.identity(default='no identity')
+        'no identity'
 
         """
         if nc_only:
@@ -882,7 +919,29 @@ class Domain(mixin.FieldDomain, mixin.Properties, cfdm.Domain):
 
         **Examples:**
 
-            TODO
+        >>> d = cf.example_field(0).domain
+        >>> print(d)
+        Dimension coords: latitude(5) = [-75.0, ..., 75.0] degrees_north
+                        : longitude(8) = [22.5, ..., 337.5] degrees_east
+                        : time(1) = [2019-01-01 00:00:00]
+        >>> d.match_by_construct("latitude")
+        True
+        >>> d.match_by_construct("air_pressure")
+        False
+        >>> d.match_by_construct("longitude", "time")
+        True
+        >>> d.match_by_construct(longitude=22.5)
+        True
+        >>> d.match_by_construct(longitude=15.5)
+        False
+        >>> d.match_by_construct(longitude=cf.gt(340))
+        False
+        >>> d.match_by_construct(longitude=cf.gt(240))
+        True
+        >>> d.match_by_construct(time=cf.dt("2019-01-01"))
+        True
+        >>> d.match_by_construct(time=cf.dt("2020-01-01"))
+        False
 
         """
         if identities:
