@@ -11,14 +11,13 @@ faulthandler.enable()  # to debug seg faults and timeouts
 
 import cf
 
-
 tmpfile = tempfile.mkstemp(".nc")[1]
 tmpfile2 = tempfile.mkstemp(".nca")[1]
 tmpfiles = [tmpfile, tmpfile2, "delme.nc", "delme.nca"]
 
 
 def _remove_tmpfiles():
-    """TODO."""
+    """Try to remove defined temporary files by deleting their paths."""
     for f in tmpfiles:
         try:
             os.remove(f)
